==> tsghc-0.0.3.tgz: package/README.md <==
<img src='https://github.com/ljlm0402/tsghc/raw/images/logo.jpg' border='0' alt='logo' />

[TypeScript's](https://www.npmjs.com/package/typescript) [GitHub](https://github.com/) CLI Tool.

<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/v/tsghc.svg" alt="NPM Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/l/tsghc.svg" alt="Package License" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/github/v/release/ljlm0402/tsghc" alt="Release Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/dm/tsghc.svg" alt="NPM Downloads" /></a>

<br />

## 🌈 tsghc?

tsghc is a CLI module that quickly fetches and uses Repositories composed of TypeScript.

## 🚀 Quick Start

### Install with the npm global package

```sh
$ npm install -g tsghc
```

### CLI tsghc

```sh
$ tsghc
```

<img src='https://github.com/ljlm0402/tsghc/raw/images/cli.gif' border='0' alt='cli' />

## 📩 Please tell us your Repositories

Add it to the template folder file according to your repo's framework.

```js
{
    name: '<repo_name>',
    url: '<repo_url>',
    author: '<your_name>'
}
```

## 📬 Recommended Commit Message

|  When |  Commit Message  |
|:--------|:-----------|
| Add function | feat: ⚡️ Add function |
| Fix bug | fix: 🐞 Fix bug |
| Refactoring | refactor: 🛠 Refactoring |
| Add package | package: 📦 Add package |
| Fix readme | docs: 📚 Fix readme |
| Improvements style | style: 👁 Improvements style |
| New Releases | releases: 🎉 Releases |

## 💳 License

[MIT](LICENSE)

==> tsghc-1.0.0.tgz: package/README.md <==
<img src='https://github.com/ljlm0402/tsghc/raw/images/logo.jpg' border='0' alt='logo' />

[TypeScript's](https://www.npmjs.com/package/typescript) [GitHub](https://github.com/) CLI Tool.

<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/v/tsghc.svg" alt="NPM Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/l/tsghc.svg" alt="Package License" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/github/v/release/ljlm0402/tsghc" alt="Release Version" /></a>
<a href="https://www.npmjs.com/package/tsghc" target="_blank"><img src="https://img.shields.io/npm/dm/tsghc.svg" alt="NPM Downloads" /></a>

<br />

## 🌈 tsghc?

__tsghc__ is a CLI module that quickly fetches and uses Repositories composed of TypeScript.

## 🚀 Quick Start

### Install with the npm global package

```sh
$ npm install -g tsghc
```

### CLI tsghc

```sh
$ tsghc
```

<img src='https://github.com/ljlm0402/tsghc/raw/images/cli.gif' border='0' alt='cli' />

## 🤝 Please pull request from your repository.

Add it to the template folder file according to your repo's framework.

```js
{
    name: '<repo_name>',
    url: '<repo_url>',
    author: '<your_name>'
}
```

## 📬 Recommended Commit Message

|  When |  Commit Message  |
|:--------|:-----------|
| Add function | feat: ⚡️ Add function |
| Fix bug | fix: 🐞 Fix bug |
| Refactoring | refactor: 🛠 Refactoring |
| Add package | package: 📦 Add package |
| Fix readme | docs: 📚 Fix readme |
| Improvements style | style: 👁 Improvements style |
| New Releases | releases: 🎉 Releases |

## 💳 License

[MIT](LICENSE)
